@@ -40,7 +40,7 @@ sub DEBUG { 0 }
 
 sub create_ikc_channel
 {
-  my($handle, $name, $on_connect, $subscribe) = @_;
+  my($handle, $name, $on_connect, $subscribe, $rname) = @_;
 
   new POE::Session( _start => \&channel_start,
                     _stop  => \&channel_shutdown,
@@ -58,17 +58,16 @@ sub create_ikc_channel
                     client_001 => \&negociate_001,
                     client_002 => \&client_002,
                     client_003 => \&client_003,
-                    [ $handle, $name, $on_connect, $subscribe]
+                    [ $handle, $name, $on_connect, $subscribe, $rname]
                   );
 }
 
 #----------------------------------------------------
 # Accept POE's standard _start event, and begin processing data.
-
 sub channel_start 
 {
-    my ($kernel, $heap, $session, $handle, $name, $on_connect, $subscribe) = 
-                @_[KERNEL, HEAP, SESSION, ARG0, ARG1, ARG2, ARG3];
+    my ($kernel, $heap, $session, $handle, $name, $on_connect, $subscribe, $rname) = 
+                @_[KERNEL, HEAP, SESSION, ARG0, ARG1, ARG2, ARG3, ARG4];
 
     my @name=unpack_sockaddr_in(getsockname($handle));
     $name[1]=inet_ntoa($name[1]);
@@ -83,9 +82,15 @@ sub channel_start
     }
     
 
-    @name=unpack_sockaddr_in(getpeername($handle));
-    $name[1]=inet_ntoa($name[1]);
-    $heap->{remote_kernel}=join ':', @name[1,0];
+    if($rname)
+    {
+        $heap->{remote_kernel}=$rname; 
+    } else
+    {
+        @name=unpack_sockaddr_in(getpeername($handle));
+        $name[1]=inet_ntoa($name[1]);
+        $heap->{remote_kernel}=join ':', @name[1,0];
+    }
 
     DEBUG && print "Channel session $heap->{kernel_name}<->$heap->{remote_kernel} created.\n";
 
@@ -283,6 +288,7 @@ sub server_003
             $heap->{wheel_client}->put('NOT');
         } else
         {
+            DEBUG && print "Using $package\n";
             $heap->{wheel_client}->put('OK');
         }
     } elsif($line eq 'WORLD')
