@@ -37,7 +37,7 @@ sub create_ikc_client
 {
     my(%parms)=@_;
     $parms{on_connect}||=sub{};         # would be silly for this to be blank
-    $parms{ip}||='0.0.0.0';             # INET_ANY
+    $parms{ip}||='localhost';           
     $parms{port}||=603;                 # POE! (almost :)
     $parms{name}||="Client$$";
     $parms{subscribe}||=[];
@@ -60,6 +60,7 @@ sub _start {
       SuccessState   => 'connected',    # generating this event on connection
       FailureState   => 'error'         # generating this event on error
     );
+  $heap->{remote_name}="$parms->{ip}:$parms->{port}";
   $heap->{on_connect}=$parms->{on_connect};
   $heap->{name}=$parms->{name};
   $heap->{subscribe}=$parms->{subscribe};
@@ -88,8 +89,8 @@ sub connected
 
                         # give the connection to a channel
     create_ikc_channel($handle, $heap->{name}, $heap->{on_connect}, 
-                                $heap->{subscribe});
-    delete @{$heap}{qw(name on_connect subscribe)};
+                                $heap->{subscribe}, $heap->{remote_name});
+    delete @{$heap}{qw(name on_connect subscribe remote_name)};
     
 }
 
