@@ -42,7 +42,7 @@ sub create_ikc_responder
                       remote_error
                       register unregister default  
                       publish retract subscribe unsubscribe
-                      do_you_have
+                      do_you_have ping
                     )]);
 }
 
@@ -65,6 +65,7 @@ sub request
     my($kernel, $heap, $request) = @_[KERNEL, HEAP, ARG0];
     $heap->{self}->request($request);
 }
+
 #----------------------------------------------------
 # Register foreign kernels so that we can send states to them
 sub register
@@ -129,7 +130,7 @@ sub remote_error
 sub publish
 {
     my($kernel, $heap, $sender, $session, $states)=
-        @_[KERNEL, HEAP, SENDER, ARG0, ARG1];
+      @_[KERNEL, HEAP, SENDER,  ARG0,     ARG1];
     $session||=$sender;
     $heap->{self}->publish($session, $states);
 }
@@ -162,7 +163,7 @@ sub subscribe
             $kernel->post($sender, $state, @_);
         };
     }
-    $heap->{self}->subscribe($sessions, $callback, $sender->{'ID'});
+    $heap->{self}->subscribe($sessions, $callback, $sender->ID);
 }
 
 # Called by a foreign IKC session 
@@ -201,6 +202,11 @@ sub unsubscribe
 }
 
 
+#----------------------------------------------------
+sub ping
+{
+    "PONG";
+}
 
 
 
@@ -229,8 +235,9 @@ sub new
     my($package, $kernel, $session)=@_;
     my $self=bless 
         {
-            'local'=>{IKC=>{remote_error=>1,
+            'local'=>{IKC=>{remote_error=>1, # these states are auto-published
                             do_you_have=>1,
+                            ping=>1,
                            },
                      },
             remote=>{},
@@ -256,17 +263,17 @@ sub request
     my $to=specifier_parse($request->{event});
     eval
     {
+        die "$request->{event} isn't a valid specifier" unless $to;
         my $args=$request->{params};
         # allow proxied states to have multiple ARGs
         if($to->{state} eq 'IKC:proxy')   
         {
             $to->{state}=$args->[0];
             $args=$args->[1];
-            DEBUG2 && print "IKC proxied request for ", specifier_name($to), "\n";
-                
+            DEBUG && print "IKC proxied request for ", specifier_name($to), "\n";
         } else
         {
-            DEBUG2 && print "IKC request for ", specifier_name($to), "\n";
+            DEBUG && print "IKC request for ", specifier_name($to), "\n";
             $args=[$args];
         }
           
@@ -330,7 +337,7 @@ sub register
 
     foreach my $name (@todo)
     {
-        DEBUG && print $name, ' ';
+        DEBUG && print "'$name' ";
         $self->{kernel}{$name}=$rid;
         $self->{remote}{$name}||=[];
     }
@@ -391,11 +398,14 @@ sub unregister
             # already gone...
         }
                 # tell the proxies they are no longer needed
-        foreach my $alias (@{$self->{remote}{$name}})
+        if($name)
         {
-            $self->{poe_kernel}->post($alias, '_delete');
+            foreach my $alias (@{$self->{remote}{$name}})
+            {
+                $self->{poe_kernel}->post($alias, '_delete');
+            }
+            delete $self->{remote}{$name};
         }
-        delete $self->{remote}{$name};
     }
     return 1;
 }
@@ -436,12 +446,12 @@ sub send_msg
         return;
     }
 
-    DEBUG2 && print "poe:/IKC/$e to ", specifier_name($to), "\n";
+    DEBUG2 && print "poe:/IKC/$e to '", specifier_name($to), "'\n";
 
     # This way the thunk session will proxy a request back to us
     if($sender)
     {
-        $sender=$sender->{ID} if ref $sender;
+        $sender=$sender->ID if ref $sender;
         $msg->{from}={  kernel=>$self->{poe_kernel}->ID,
                         session=>$sender,
                         state=>'IKC:proxy',
@@ -558,9 +568,9 @@ sub call
         return;
     }
 
-    # Question : should $svp->{session} be forced to be the sender?
+    # Question : should $rsvp->{session} be forced to be the sender?
     # or will we allow people to point callbacks to other poe:kernel/sessions
-    $rsvp->{session}||=$sender->{ID} if ref $sender;    # maybe a session ID?
+    $rsvp->{session}||=$sender->ID if ref $sender;    # maybe a session ID?
     if(not $rsvp->{session})                            # no session alias
     {
         die "IKC call requires session IDs, please patch your version of POE\n";
@@ -593,6 +603,8 @@ sub publish
 
     $self->{'local'}->{$session}||={};
     my $p=$self->{'local'}->{$session};
+
+    die "\$states isn't an array ref" unless ref($states) eq 'ARRAY';
     foreach my $q (@$states)
     {
         DEBUG && print "Published poe:/$session/$q\n";
@@ -803,7 +815,11 @@ sub unsubscribe
     croak "Not done";
 }
 
-
+#----------------------------------------------------
+sub ping
+{
+    "PONG";
+}
 
 ##############################################################################
 # These are Thunks used to post the actual state on behalf of the foreign
